@@ -2,7 +2,7 @@
  *
  * rdf_serializer.h - RDF Serializer Factory / Serializer interfaces and definition
  *
- * Copyright (C) 2002-2008, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2002-2009, David Beckett http://www.dajobe.org/
  * Copyright (C) 2002-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
@@ -36,14 +36,18 @@
 extern "C" {
 #endif
 
-#include <raptor.h>
+#include <raptor2.h>
 
 /* class methods */
 REDLAND_API
 void librdf_serializer_register_factory(librdf_world *world, const char *name, const char *label, const char *mime_type, const unsigned char *uri_string, void (*factory) (librdf_serializer_factory*));
 
-REDLAND_API
+REDLAND_API REDLAND_DEPRECATED
 int librdf_serializer_enumerate(librdf_world* world, const unsigned int counter, const char **name, const char **label);
+REDLAND_API
+const raptor_syntax_description* librdf_serializer_get_description(librdf_world* world, unsigned int counter);
+REDLAND_API
+int librdf_serializer_check_name(librdf_world* world, const char *name);
 
 /* constructor */
 REDLAND_API
